# Installation

The package can be installed via `pip`, `conda`, or `mamba`.

## pip

Run the following in a terminal.

```bash
python3 -m venv my_venv_for_globalign
source my_venv_for_globalign/bin/activate
pip install globalign
```

## Check Installation

Try running 

```bash
globaligner --version
```
